@@ -185,7 +185,7 @@ class SubprocessFactoryImpl:
                 self._terminal.kill()
             try:
                 # Allow the process to exit by itself in case slow_stop is True
-                self._terminal.wait(5)
+                self._terminal.wait(10)
             except subprocess.TimeoutExpired:
                 # The process failed to stop, no worries, we'll make sure it exit along with it's
                 # child processes bellow
@@ -372,7 +372,7 @@ class ProcessFactory(SubprocessFactoryBase):
     @default_timeout.default
     def _set_default_timeout(self):
         if not sys.platform.startswith(("win", "darwin")):
-            return 30
+            return 60
         # Windows and macOS are just slower.
         return 120
 
@@ -565,7 +565,7 @@ class DaemonFactoryImpl(SubprocessFactoryImpl):
             stdout=result.stdout,
             stderr=result.stderr,
             exitcode=result.exitcode,
-            cmdline=run_arguments,
+            cmdline=result.cmdline,
         )
 
     def terminate(self):
@@ -720,12 +720,12 @@ class DaemonFactory(SubprocessFactoryBase):
     def _add_factory_to_stats_processes(self):
         if self.factories_manager and self.factories_manager.stats_processes is not None:
             display_name = self.get_display_name()
-            self.factories_manager.stats_processes[display_name] = psutil.Process(self.pid)
+            self.factories_manager.stats_processes.add(display_name, self.pid)
 
     def _remove_factory_from_stats_processes(self):
         if self.factories_manager and self.factories_manager.stats_processes is not None:
             display_name = self.get_display_name()
-            self.factories_manager.stats_processes.pop(display_name, None)
+            self.factories_manager.stats_processes.remove(display_name)
 
     def _terminate_processes_matching_listen_ports(self):
         if not self.listen_ports:
@@ -908,12 +908,11 @@ class SaltCliFactory(SaltFactory, ProcessFactory):
             self.__merge_json_output__ = merge_json_output
         cmdline = []
 
-        args = list(args)
+        # Convert all passed in arguments to strings
+        args = [str(arg) for arg in args]
 
         # Handle the config directory flag
         for arg in args:
-            if not isinstance(arg, str):
-                continue
             if arg.startswith("--config-dir="):
                 break
             if arg in ("-c", "--config-dir"):
@@ -925,8 +924,6 @@ class SaltCliFactory(SaltFactory, ProcessFactory):
         if self.__cli_timeout_supported__:
             salt_cli_timeout_next = False
             for arg in args:
-                if not isinstance(arg, str):
-                    continue
                 if arg.startswith("--timeout="):
                     # Let's actually change the _terminal_timeout value which is used to
                     # calculate when the run() method should actually timeout
@@ -936,7 +933,7 @@ class SaltCliFactory(SaltFactory, ProcessFactory):
                         # Not a number? Let salt do it's error handling
                         break
                     if salt_cli_timeout >= self.impl._terminal_timeout:
-                        self.impl._terminal_timeout = int(salt_cli_timeout) + 5
+                        self.impl._terminal_timeout = int(salt_cli_timeout) + 10
                     break
                 if salt_cli_timeout_next:
                     try:
@@ -945,28 +942,23 @@ class SaltCliFactory(SaltFactory, ProcessFactory):
                         # Not a number? Let salt do it's error handling
                         break
                     if salt_cli_timeout >= self.impl._terminal_timeout:
-                        self.impl._terminal_timeout = int(salt_cli_timeout) + 5
+                        self.impl._terminal_timeout = int(salt_cli_timeout) + 10
                     break
                 if arg == "-t" or arg.startswith("--timeout"):
                     salt_cli_timeout_next = True
                     continue
             else:
-                # Always shave off 5 seconds to the passed --timeout argument so that the salt command times out
-                # before the terminal does
+                # Pass the default timeout to salt and increase the internal timeout by 10 seconds to
+                # allow salt to exit cleanly.
                 salt_cli_timeout = self.impl._terminal_timeout
                 if salt_cli_timeout:
-                    # Shave off a few seconds so that the salt command times out before the terminal does
-                    salt_cli_timeout -= 5
-                if salt_cli_timeout:
-                    # If it's still a positive number, add it to the salt command CLI flags
+                    self.impl._terminal_timeout = salt_cli_timeout + 10
+                    # Add it to the salt command CLI flags
                     cmdline.append("--timeout={}".format(salt_cli_timeout))
 
         # Handle the output flag
         if self.__cli_output_supported__:
-            json_output = False
             for idx, arg in enumerate(args):
-                if not isinstance(arg, str):
-                    continue
                 if arg in ("--out", "--output"):
                     self.__json_output__ = args[idx + 1] == "json"
                     break
@@ -979,8 +971,6 @@ class SaltCliFactory(SaltFactory, ProcessFactory):
                 self.__json_output__ = True
             if self.__json_output__:
                 for arg in args:
-                    if not isinstance(arg, str):
-                        continue
                     if arg in ("--out-indent", "--output-indent"):
                         break
                     if arg.startswith(("--out-indent=", "--output-indent=")):
@@ -992,8 +982,6 @@ class SaltCliFactory(SaltFactory, ProcessFactory):
         if self.__cli_log_level_supported__:
             # Handle the logging flag
             for arg in args:
-                if not isinstance(arg, str):
-                    continue
                 if arg in ("-l", "--log-level"):
                     break
                 if arg.startswith("--log-level="):
@@ -1122,16 +1110,11 @@ class SystemdSaltDaemonFactoryImpl(DaemonFactoryImpl):
         return process_result
 
     def start(self, *extra_cli_arguments, max_start_attempts=None, start_timeout=None):
-        try:
-            return super().start(
-                *extra_cli_arguments,
-                max_start_attempts=max_start_attempts,
-                start_timeout=start_timeout
-            )
-        except FactoryNotStarted:  # pylint: disable=try-except-raise
-            raise
-        else:
-            atexit.register(self.terminate)
+        started = super().start(
+            *extra_cli_arguments, max_start_attempts=max_start_attempts, start_timeout=start_timeout
+        )
+        atexit.register(self.terminate)
+        return started
 
     def _terminate(self):
         """
